@@ -1,4 +1,3 @@
-
 test_that("antpath", {
   m <- leaflet() %>%
     addAntpath(data = atlStorms2005, layerId = "id")
@@ -8,11 +7,14 @@ test_that("antpath", {
   expect_equal(deps[[length(deps)]]$name, "lfx-antpath")
 
   m <- m %>% removeAntpath(layerId = "id")
-  expect_equal(m$x$calls[[length(m$x$calls)]]$method,
-               "removeAntpath")
+  expect_equal(
+    m$x$calls[[length(m$x$calls)]]$method,
+    "removeAntpath"
+  )
 
   m <- m %>% clearAntpath()
-  expect_equal(m$x$calls[[length(m$x$calls)]]$method,
-               "clearAntpath")
-
+  expect_equal(
+    m$x$calls[[length(m$x$calls)]]$method,
+    "clearAntpath"
+  )
 })
