@@ -1,6 +1,4 @@
-
 test_that("history", {
-
   m <- leaflet() %>%
     addTiles(group = "base") %>%
     fitBounds(-72, 40, -70, 43) %>%
@@ -14,19 +12,26 @@ test_that("history", {
 
   m <- m %>%
     goBackHistory()
-  expect_equal(m$x$calls[[length(m$x$calls)]]$method,
-               "goBackHistory")
+  expect_equal(
+    m$x$calls[[length(m$x$calls)]]$method,
+    "goBackHistory"
+  )
 
   m <- m %>% goForwardHistory()
-  expect_equal(m$x$calls[[length(m$x$calls)]]$method,
-               "goForwardHistory")
+  expect_equal(
+    m$x$calls[[length(m$x$calls)]]$method,
+    "goForwardHistory"
+  )
 
   m <- m %>% clearFuture()
-  expect_equal(m$x$calls[[length(m$x$calls)]]$method,
-               "clearFuture")
+  expect_equal(
+    m$x$calls[[length(m$x$calls)]]$method,
+    "clearFuture"
+  )
 
   m <- m %>% clearHistory()
-  expect_equal(m$x$calls[[length(m$x$calls)]]$method,
-               "clearHistory")
-
+  expect_equal(
+    m$x$calls[[length(m$x$calls)]]$method,
+    "clearHistory"
+  )
 })
